const LICENSE_SERVER_URL = "https://config.gravity.global/gravity/services/extension/config?url=" + encodeURI(location.href);
const IS_GRAVITY_ENABLED = "services/info/gravity/enabled?url=" + encodeURI(location.href);

(function init() {
    browser.storage.sync.get(["baseUrl", "baseUrlLifeTime", "baseUrlCreationTime"], function (response) {
        if (response.baseUrl && isBaseUrlValid(response.baseUrlLifeTime, response.baseUrlCreationTime)) {
            isGravityEnabled(response.baseUrl)
        } else {
            getServerBaseUrl();
        }
    });
})();

function getServerBaseUrl() {
    var xhr = new XMLHttpRequest();
    xhr.onreadystatechange = function() {
        if (xhr.readyState === 4 && xhr.status === 200) {
            var response = JSON.parse(xhr.responseText);
            const baseUrl = response.serverUrl;
            const baseUrlLifeTime = response.serverUrlLifeTime;
            if (baseUrl && baseUrlLifeTime) {
                saveDataToExtensionStorage(baseUrl, baseUrlLifeTime);
                isGravityEnabled(baseUrl);
            }
        }
    };
    xhr.open("GET", LICENSE_SERVER_URL, true);
    xhr.send();
}

function isGravityEnabled(baseUrl) {
    var xhr = new XMLHttpRequest();
    xhr.onreadystatechange = function() {
        if (xhr.readyState === 4 && xhr.status === 200) {
            if (xhr.responseText === "true") { // if enabled
                loadInjectScripts(baseUrl);
            }
        }
    };
    xhr.open("GET", baseUrl + IS_GRAVITY_ENABLED, true);
    xhr.send();
}

function loadInjectScripts(baseUrl) {
    var scriptUrl = baseUrl + "inject/";
    var script = document.createElement('script');
    script.onload = function () {
        var startScript = document.createElement('script');
        var srcBody = document.createTextNode("pi.gravity.inject.setup('" + baseUrl + "', '" + scriptUrl + "')");
        startScript.appendChild(srcBody);
        document.head.appendChild(startScript);
    };
    script.src = scriptUrl + "js/pi.gravity.inject.js";
    document.head.appendChild(script);
}

function saveDataToExtensionStorage(baseUrl, baseUrlLifeTime) {
    browser.storage.sync.set({"baseUrl": baseUrl});
    browser.storage.sync.set({"baseUrlLifeTime": baseUrlLifeTime});
    browser.storage.sync.set({"baseUrlCreationTime": new Date().getTime()});
}

function isBaseUrlValid(baseUrlLifeTime, baseUrlCreationTime) {
    const currentTimestamp = new Date().getTime();
    return currentTimestamp - baseUrlCreationTime < baseUrlLifeTime;
}

